/* $Id: standard.h,v 1.4 2000/02/19 16:20:53 proff Exp $
 * $Copyright$
 */

#ifndef STANDARD_H
#define STANDARD_H

#define _X_OPEN_SOURCE
#define __USE_XOPEN
#define __USE_XOPEN_EXTENDED

#include "nconf.h"
#include "ntypes.h"

#include <stdio.h>
#ifdef HAVE_UNISTD_H
#  include <unistd.h>
#endif
#ifdef HAVE_STDLIB_H
#  include <stdlib.h>
#endif
#ifdef HAVE_STDARG_H
#  include <stdarg.h>
#endif
#ifdef HAVE_SYS_UNISTD_H
#  include <sys/unistd.h>
#endif
#include <sys/types.h>
#ifdef HAVE_SYS_PARAM_H
#  include <sys/param.h>
#endif
#include <errno.h>
#ifndef __USE_GNU
#  define __USE_GNU
#  define USE_GNU_SET
#endif
#include <string.h>
#ifdef USE_GNU_SET
#  undef __USE_GNU
#endif
#include <syslog.h>
#include <ctype.h>
#include <sys/times.h>
#ifndef LOG_NEWS
#  ifdef NEWS_NOTICE
#    define LOG_NEWS NEWS_NOTICE
#  else
#    define LOG_NEWS LOG_DAEMON
#  endif
#endif
#include <time.h>
#ifdef HAVE_SYS_TIME_H
#  include <sys/time.h>
#endif
#include <signal.h>
#ifdef HAVE_SYS_FILE_H
#  include <sys/file.h>
#endif
#include <sys/stat.h>
#ifdef HAVE_UTIME_H
#  include <utime.h>
#endif
#ifdef HAVE_FCNTL_H
#  include <fcntl.h>
#endif
#ifdef HAVE_SYS_IOCTL_H
#  include <sys/ioctl.h>
#endif
#include <pwd.h>
#include <grp.h>
#include <sys/types.h>
#include <sys/wait.h>
#ifdef HAVE_LIBUTIL_H
#  include <libutil.h>
#endif
#ifndef CLK_TCK
#  define CLK_TCK HZ
#endif
#ifndef HAVE_MEMMOVE
#  define memmove(dst,src,len) bcopy(src,dst,len)
#endif
#ifdef HAVE_SYS_RESOURCE_H
#  include <sys/resource.h>
#endif

#endif /* STANDARD_H */
